.. _authors:

*******
Authors
*******

Mopidy is copyright 2009-2019 Stein Magnus Jodal and contributors. Mopidy is
licensed under the `Apache License, Version 2.0
<http://www.apache.org/licenses/LICENSE-2.0>`_.

The following persons have contributed to Mopidy. The list is in the order of
first contribution. For details on who have contributed what, please refer to
our Git repository.

.. include:: ../AUTHORS

If want to help us making Mopidy better, the best way to do so is to contribute
back to the community, either through code, documentation, tests, bug reports,
or by helping other users, spreading the word, etc. See :ref:`contributing` for
a head start.
